@@ -37,7 +37,7 @@ type ScanOptions struct {
 }
 
 type DriftCTL struct {
-	remoteSupplier           resource.RemoteSupplier
+	remoteSupplier           resource.Supplier
 	iacSupplier              resource.Supplier
 	alerter                  alerter.AlerterInterface
 	analyzer                 *analyser.Analyzer
@@ -49,7 +49,7 @@ type DriftCTL struct {
 	store                    memstore.Store
 }
 
-func NewDriftCTL(remoteSupplier resource.RemoteSupplier,
+func NewDriftCTL(remoteSupplier resource.Supplier,
 	iacSupplier resource.Supplier,
 	alerter *alerter.Alerter,
 	analyzer *analyser.Analyzer,
@@ -75,7 +75,7 @@ func NewDriftCTL(remoteSupplier resource.RemoteSupplier,
 
 func (d DriftCTL) Run() (*analyser.Analysis, error) {
 	start := time.Now()
-	remoteResources, resourcesFromState, err := d.enumerateResources()
+	remoteResources, resourcesFromState, err := d.scan()
 	if err != nil {
 		return nil, err
 	}
@@ -149,23 +149,11 @@ func (d DriftCTL) Run() (*analyser.Analysis, error) {
 		}
 	}
 
-	analysis := analyser.NewAnalysis(analyser.AnalyzerOptions{Deep: d.opts.Deep})
-	analysis = d.analyzer.CompareEnumeration(analysis, remoteResources, resourcesFromState)
+	analysis, err := d.analyzer.Analyze(remoteResources, resourcesFromState)
 	if err != nil {
 		return nil, err
 	}
 
-	managedResources, err := d.readResources(analysis.Managed())
-	if err != nil {
-		return nil, err
-	}
-
-	analysis = d.analyzer.CompleteAnalysis(analysis, managedResources, resourcesFromState)
-
-	// Sort resources by Terraform Id
-	// The purpose is to have a predictable output
-	analysis.SortResources()
-
 	analysis.Duration = time.Since(start)
 	analysis.Date = time.Now()
 
@@ -173,7 +161,7 @@ func (d DriftCTL) Run() (*analyser.Analysis, error) {
 	d.store.Bucket(memstore.TelemetryBucket).Set("total_managed", analysis.Summary().TotalManaged)
 	d.store.Bucket(memstore.TelemetryBucket).Set("duration", uint(analysis.Duration.Seconds()+0.5))
 
-	return analysis, nil
+	return &analysis, nil
 }
 
 func (d DriftCTL) Stop() {
@@ -191,7 +179,7 @@ func (d DriftCTL) Stop() {
 	}
 }
 
-func (d DriftCTL) enumerateResources() (remoteResources []*resource.Resource, resourcesFromState []*resource.Resource, err error) {
+func (d DriftCTL) scan() (remoteResources []*resource.Resource, resourcesFromState []*resource.Resource, err error) {
 	logrus.Info("Start reading IaC")
 	d.iacProgress.Start()
 	resourcesFromState, err = d.iacSupplier.Resources()
@@ -200,20 +188,13 @@ func (d DriftCTL) enumerateResources() (remoteResources []*resource.Resource, re
 		return nil, nil, err
 	}
 
-	logrus.Info("Start enumerating cloud provider resources")
+	logrus.Info("Start scanning cloud provider")
 	d.scanProgress.Start()
 	defer d.scanProgress.Stop()
-	remoteResources, err = d.remoteSupplier.EnumerateResources()
+	remoteResources, err = d.remoteSupplier.Resources()
 	if err != nil {
 		return nil, nil, err
 	}
 
 	return remoteResources, resourcesFromState, err
 }
-
-func (d DriftCTL) readResources(managedResources []*resource.Resource) ([]*resource.Resource, error) {
-	logrus.WithField("count", len(managedResources)).Info("Fetching details of managed resources")
-	d.scanProgress.Start()
-	defer d.scanProgress.Stop()
-	return d.remoteSupplier.ReadResources(managedResources)
-}
