@@ -102,75 +102,75 @@ func TestTerraformStateReader_AWS_Resources(t *testing.T) {
 	}{
 		{name: "IAM user module", dirName: "module.iam_iam-user", wantErr: false},
 		{name: "Data source", dirName: "data_source", wantErr: false},
-		{name: "Route 53 zone", dirName: "route53_zone", wantErr: false},
-		{name: "Route 53 record - single record", dirName: "route53_record", wantErr: false},
-		{name: "Route 53 record - multiples zones, multiples records", dirName: "route53_record_multiples", wantErr: false},
-		{name: "Route 53 record - empty records", dirName: "route53_record_null_records", wantErr: false},
-		{name: "s3 full", dirName: "s3_full", wantErr: false},
-		{name: "RDS DB instance", dirName: "db_instance", wantErr: false},
-		{name: "RDS DB Subnet group", dirName: "db_subnet_group", wantErr: false},
-		{name: "Lambda function", dirName: "lambda_function", wantErr: false},
+		{name: "Route 53 zone", dirName: "aws_route53_zone", wantErr: false},
+		{name: "Route 53 record - single record", dirName: "aws_route53_record", wantErr: false},
+		{name: "Route 53 record - multiples zones, multiples records", dirName: "aws_route53_record_multiples", wantErr: false},
+		{name: "Route 53 record - empty records", dirName: "aws_route53_record_null_records", wantErr: false},
+		{name: "s3 full", dirName: "aws_s3_full", wantErr: false},
+		{name: "RDS DB instance", dirName: "aws_db_instance", wantErr: false},
+		{name: "RDS DB Subnet group", dirName: "aws_db_subnet_group", wantErr: false},
+		{name: "Lambda function", dirName: "aws_lambda_function", wantErr: false},
 		{name: "unsupported attribute", dirName: "unsupported_attribute", wantErr: false},
 		{name: "Unsupported provider", dirName: "unsupported_provider", wantErr: false},
 		{name: "Unsupported resource", dirName: "unsupported_resource", wantErr: false},
-		{name: "EC2 instance", dirName: "ec2_instance", wantErr: false},
-		{name: "EC2 key pair", dirName: "ec2_key_pair", wantErr: false},
-		{name: "EC2 ami", dirName: "ec2_ami", wantErr: false},
-		{name: "EC2 eip", dirName: "ec2_eip", wantErr: false},
-		{name: "EC2 eip with its association", dirName: "ec2_eip_association", wantErr: false},
-		{name: "EC2 ebs volume", dirName: "ec2_ebs_volume", wantErr: false},
-		{name: "EC2 ebs snapshot", dirName: "ec2_ebs_snapshot", wantErr: false},
-		{name: "VPC security group", dirName: "vpc_security_group", wantErr: false},
-		{name: "IAM Users", dirName: "iam_user_multiple", wantErr: false},
-		{name: "IAM User Policy", dirName: "iam_user_policy_multiple", wantErr: false},
-		{name: "IAM access keys", dirName: "iam_access_key_multiple", wantErr: false},
-		{name: "IAM role", dirName: "iam_role_multiple", wantErr: false},
-		{name: "IAM policy", dirName: "iam_policy_multiple", wantErr: false},
-		{name: "IAM role policy", dirName: "iam_role_policy_multiple", wantErr: false},
-		{name: "IAM role policy attachment", dirName: "iam_role_policy_attachment", wantErr: false},
-		{name: "IAM user policy attachment", dirName: "iam_user_policy_attachment", wantErr: false},
-		{name: "VPC security group rule", dirName: "vpc_security_group_rule", wantErr: false},
-		{name: "route table", dirName: "route_table", wantErr: false},
-		{name: "route", dirName: "route", wantErr: false},
-		{name: "route table associations", dirName: "route_assoc", wantErr: false},
+		{name: "EC2 instance", dirName: "aws_ec2_instance", wantErr: false},
+		{name: "EC2 key pair", dirName: "aws_ec2_key_pair", wantErr: false},
+		{name: "EC2 ami", dirName: "aws_ec2_ami", wantErr: false},
+		{name: "EC2 eip", dirName: "aws_ec2_eip", wantErr: false},
+		{name: "EC2 eip with its association", dirName: "aws_ec2_eip_association", wantErr: false},
+		{name: "EC2 ebs volume", dirName: "aws_ec2_ebs_volume", wantErr: false},
+		{name: "EC2 ebs snapshot", dirName: "aws_ec2_ebs_snapshot", wantErr: false},
+		{name: "VPC security group", dirName: "aws_vpc_security_group", wantErr: false},
+		{name: "IAM Users", dirName: "aws_iam_user_multiple", wantErr: false},
+		{name: "IAM User Policy", dirName: "aws_iam_user_policy_multiple", wantErr: false},
+		{name: "IAM access keys", dirName: "aws_iam_access_key_multiple", wantErr: false},
+		{name: "IAM role", dirName: "aws_iam_role_multiple", wantErr: false},
+		{name: "IAM policy", dirName: "aws_iam_policy_multiple", wantErr: false},
+		{name: "IAM role policy", dirName: "aws_iam_role_policy_multiple", wantErr: false},
+		{name: "IAM role policy attachment", dirName: "aws_iam_role_policy_attachment", wantErr: false},
+		{name: "IAM user policy attachment", dirName: "aws_iam_user_policy_attachment", wantErr: false},
+		{name: "VPC security group rule", dirName: "aws_vpc_security_group_rule", wantErr: false},
+		{name: "route table", dirName: "aws_route_table", wantErr: false},
+		{name: "route table associations", dirName: "aws_route_assoc", wantErr: false},
+		{name: "route", dirName: "aws_route", wantErr: false},
 		{name: "NAT gateway", dirName: "aws_nat_gateway", wantErr: false},
-		{name: "Internet Gateway", dirName: "internet_gateway", wantErr: false},
-		{name: "SQS queue", dirName: "sqs_queue", wantErr: false},
-		{name: "SQS queue policy", dirName: "sqs_queue_policy", wantErr: false},
-		{name: "SNS Topic", dirName: "sns_topic", wantErr: false},
-		{name: "SNS Topic Policy", dirName: "sns_topic_policy", wantErr: false},
-		{name: "SNS Topic Subscription", dirName: "sns_topic_subscription", wantErr: false},
-		{name: "DynamoDB table", dirName: "dynamodb_table", wantErr: false},
-		{name: "Route53 Health Check", dirName: "route53_health_check", wantErr: false},
-		{name: "Cloudfront distribution", dirName: "cloudfront_distribution", wantErr: false},
-		{name: "ECR Repository", dirName: "ecr_repository", wantErr: false},
-		{name: "KMS key", dirName: "kms_key", wantErr: false},
-		{name: "KMS alias", dirName: "kms_alias", wantErr: false},
+		{name: "Internet Gateway", dirName: "aws_internet_gateway", wantErr: false},
+		{name: "SQS queue", dirName: "aws_sqs_queue", wantErr: false},
+		{name: "SQS queue policy", dirName: "aws_sqs_queue_policy", wantErr: false},
+		{name: "SNS Topic", dirName: "aws_sns_topic", wantErr: false},
+		{name: "SNS Topic Policy", dirName: "aws_sns_topic_policy", wantErr: false},
+		{name: "SNS Topic Subscription", dirName: "aws_sns_topic_subscription", wantErr: false},
+		{name: "DynamoDB table", dirName: "aws_dynamodb_table", wantErr: false},
+		{name: "Route53 Health Check", dirName: "aws_route53_health_check", wantErr: false},
+		{name: "Cloudfront distribution", dirName: "aws_cloudfront_distribution", wantErr: false},
+		{name: "ECR Repository", dirName: "aws_ecr_repository", wantErr: false},
+		{name: "KMS key", dirName: "aws_kms_key", wantErr: false},
+		{name: "KMS alias", dirName: "aws_kms_alias", wantErr: false},
 		{name: "lambda event source mapping", dirName: "aws_lambda_event_source_mapping", wantErr: false},
-		{name: "VPC", dirName: "vpc", wantErr: false},
-		{name: "Subnet", dirName: "subnet", wantErr: false},
-		{name: "RDS cluster", dirName: "rds_cluster", wantErr: false},
-		{name: "Cloudformation stack", dirName: "cloudformation_stack", wantErr: false},
-		{name: "Api Gateway Rest Api", dirName: "api_gateway_rest_api", wantErr: false},
-		{name: "Api Gateway Account", dirName: "api_gateway_account", wantErr: false},
-		{name: "Api Gateway Api Key", dirName: "api_gateway_api_key", wantErr: false},
-		{name: "Api Gateway authorizer", dirName: "api_gateway_authorizer", wantErr: false},
-		{name: "Api Gateway stage", dirName: "api_gateway_stage", wantErr: false},
-		{name: "Api Gateway resource", dirName: "api_gateway_resource", wantErr: false},
-		{name: "Api Gateway domain name", dirName: "api_gateway_domain_name", wantErr: false},
-		{name: "Api Gateway vpc link", dirName: "api_gateway_vpc_link", wantErr: false},
-		{name: "Api Gateway V2 Api", dirName: "apigatewayv2_api", wantErr: false},
-		{name: "Api Gateway V2 Route", dirName: "apigatewayv2_route", wantErr: false},
-		{name: "Api Gateway request validator", dirName: "api_gateway_request_validator", wantErr: false},
-		{name: "Api Gateway rest api policy", dirName: "api_gateway_rest_api_policy", wantErr: false},
-		{name: "Api Gateway base path mapping", dirName: "api_gateway_base_path_mapping", wantErr: false},
-		{name: "Api Gateway method", dirName: "api_gateway_method", wantErr: false},
-		{name: "Api Gateway model", dirName: "api_gateway_model", wantErr: false},
-		{name: "Api Gateway method response", dirName: "api_gateway_method_response", wantErr: false},
-		{name: "Api Gateway gateway response", dirName: "api_gateway_gateway_response", wantErr: false},
-		{name: "Api Gateway method settings", dirName: "api_gateway_method_settings", wantErr: false},
-		{name: "Api Gateway integration", dirName: "api_gateway_integration", wantErr: false},
-		{name: "Api Gateway integration response", dirName: "api_gateway_integration_response", wantErr: false},
+		{name: "VPC", dirName: "aws_vpc", wantErr: false},
+		{name: "Subnet", dirName: "aws_subnet", wantErr: false},
+		{name: "RDS cluster", dirName: "aws_rds_cluster", wantErr: false},
+		{name: "Cloudformation stack", dirName: "aws_cloudformation_stack", wantErr: false},
+		{name: "Api Gateway Rest Api", dirName: "aws_api_gateway_rest_api", wantErr: false},
+		{name: "Api Gateway Account", dirName: "aws_api_gateway_account", wantErr: false},
+		{name: "Api Gateway Api Key", dirName: "aws_api_gateway_api_key", wantErr: false},
+		{name: "Api Gateway authorizer", dirName: "aws_api_gateway_authorizer", wantErr: false},
+		{name: "Api Gateway stage", dirName: "aws_api_gateway_stage", wantErr: false},
+		{name: "Api Gateway resource", dirName: "aws_api_gateway_resource", wantErr: false},
+		{name: "Api Gateway domain name", dirName: "aws_api_gateway_domain_name", wantErr: false},
+		{name: "Api Gateway vpc link", dirName: "aws_api_gateway_vpc_link", wantErr: false},
+		{name: "Api Gateway V2 Api", dirName: "aws_apigatewayv2_api", wantErr: false},
+		{name: "Api Gateway V2 Route", dirName: "aws_apigatewayv2_route", wantErr: false},
+		{name: "Api Gateway request validator", dirName: "aws_api_gateway_request_validator", wantErr: false},
+		{name: "Api Gateway rest api policy", dirName: "aws_api_gateway_rest_api_policy", wantErr: false},
+		{name: "Api Gateway base path mapping", dirName: "aws_api_gateway_base_path_mapping", wantErr: false},
+		{name: "Api Gateway method", dirName: "aws_api_gateway_method", wantErr: false},
+		{name: "Api Gateway model", dirName: "aws_api_gateway_model", wantErr: false},
+		{name: "Api Gateway method response", dirName: "aws_api_gateway_method_response", wantErr: false},
+		{name: "Api Gateway gateway response", dirName: "aws_api_gateway_gateway_response", wantErr: false},
+		{name: "Api Gateway method settings", dirName: "aws_api_gateway_method_settings", wantErr: false},
+		{name: "Api Gateway integration", dirName: "aws_api_gateway_integration", wantErr: false},
+		{name: "Api Gateway integration response", dirName: "aws_api_gateway_integration_response", wantErr: false},
 		{name: "Api Gateway V2 authorizer", dirName: "aws_apigatewayv2_authorizer", wantErr: false},
 		{name: "AppAutoScaling Targets", dirName: "aws_appautoscaling_target", wantErr: false},
 		{name: "network acl", dirName: "aws_network_acl", wantErr: false},
@@ -178,7 +178,7 @@ func TestTerraformStateReader_AWS_Resources(t *testing.T) {
 		{name: "default network acl", dirName: "aws_default_network_acl", wantErr: false},
 		{name: "App autoscaling policy", dirName: "aws_appautoscaling_policy", wantErr: false},
 		{name: "App autoscaling scheduled action", dirName: "aws_appautoscaling_scheduled_action", wantErr: false},
-		{name: "App gateway v2 vpc link", dirName: "apigatewayv2_vpc_link", wantErr: false},
+		{name: "App gateway v2 vpc link", dirName: "aws_apigatewayv2_vpc_link", wantErr: false},
 		{name: "Launch template", dirName: "aws_launch_template", wantErr: false},
 		{name: "Launch configuration", dirName: "aws_launch_configuration", wantErr: false},
 	}
