@@ -3,9 +3,9 @@ package aws
 import (
 	"testing"
 
-	"github.com/cloudskiff/driftctl/pkg/resource"
-	tf "github.com/cloudskiff/driftctl/pkg/terraform"
-	testresource "github.com/cloudskiff/driftctl/test/resource"
+	"github.com/snyk/driftctl/pkg/resource"
+	tf "github.com/snyk/driftctl/pkg/terraform"
+	testresource "github.com/snyk/driftctl/test/resource"
 	"github.com/stretchr/testify/assert"
 )
 
@@ -32,6 +32,9 @@ func TestAWS_Metadata_Flags(t *testing.T) {
 		AwsApiGatewayStageResourceType:                {},
 		AwsApiGatewayVpcLinkResourceType:              {},
 		AwsApiGatewayV2ApiResourceType:                {},
+		AwsApiGatewayV2RouteResourceType:              {},
+		AwsApiGatewayV2VpcLinkResourceType:            {},
+		AwsApiGatewayV2AuthorizerResourceType:         {},
 		AwsAppAutoscalingPolicyResourceType:           {resource.FlagDeepMode},
 		AwsAppAutoscalingScheduledActionResourceType:  {},
 		AwsAppAutoscalingTargetResourceType:           {resource.FlagDeepMode},
@@ -92,6 +95,8 @@ func TestAWS_Metadata_Flags(t *testing.T) {
 		AwsVpcResourceType:                            {resource.FlagDeepMode},
 		AwsSecurityGroupRuleResourceType:              {resource.FlagDeepMode},
 		AwsNetworkACLRuleResourceType:                 {resource.FlagDeepMode},
+		AwsLaunchTemplateResourceType:                 {resource.FlagDeepMode},
+		AwsLaunchConfigurationResourceType:            {},
 	}
 
 	schemaRepository := testresource.InitFakeSchemaRepository(tf.AWS, "3.19.0")
